@@ -76,33 +76,33 @@ uint64_t opt_clock_offset;
 extern int yydebug;
 
 static
-struct trace_descriptor *ctf_open_trace(const char *path, int flags,
-		void (*packet_seek)(struct stream_pos *pos, size_t index,
+struct bt_trace_descriptor *ctf_open_trace(const char *path, int flags,
+		void (*packet_seek)(struct bt_stream_pos *pos, size_t index,
 			int whence),
 		FILE *metadata_fp);
 static
-struct trace_descriptor *ctf_open_mmap_trace(
-		struct mmap_stream_list *mmap_list,
-		void (*packet_seek)(struct stream_pos *pos, size_t index,
+struct bt_trace_descriptor *ctf_open_mmap_trace(
+		struct bt_mmap_stream_list *mmap_list,
+		void (*packet_seek)(struct bt_stream_pos *pos, size_t index,
 			int whence),
 		FILE *metadata_fp);
 static
-void ctf_set_context(struct trace_descriptor *descriptor,
+void ctf_set_context(struct bt_trace_descriptor *descriptor,
 		struct bt_context *ctx);
 static
-void ctf_set_handle(struct trace_descriptor *descriptor,
+void ctf_set_handle(struct bt_trace_descriptor *descriptor,
 		struct bt_trace_handle *handle);
 
 static
-int ctf_close_trace(struct trace_descriptor *descriptor);
+int ctf_close_trace(struct bt_trace_descriptor *descriptor);
 static
-uint64_t ctf_timestamp_begin(struct trace_descriptor *descriptor,
+uint64_t ctf_timestamp_begin(struct bt_trace_descriptor *descriptor,
 		struct bt_trace_handle *handle, enum bt_clock_type type);
 static
-uint64_t ctf_timestamp_end(struct trace_descriptor *descriptor,
+uint64_t ctf_timestamp_end(struct bt_trace_descriptor *descriptor,
 		struct bt_trace_handle *handle, enum bt_clock_type type);
 static
-int ctf_convert_index_timestamp(struct trace_descriptor *tdp);
+int ctf_convert_index_timestamp(struct bt_trace_descriptor *tdp);
 
 static
 rw_dispatch read_dispatch_table[] = {
@@ -129,7 +129,7 @@ rw_dispatch write_dispatch_table[] = {
 };
 
 static
-struct format ctf_format = {
+struct bt_format ctf_format = {
 	.open_trace = ctf_open_trace,
 	.open_mmap_trace = ctf_open_mmap_trace,
 	.close_trace = ctf_close_trace,
@@ -141,7 +141,7 @@ struct format ctf_format = {
 };
 
 static
-uint64_t ctf_timestamp_begin(struct trace_descriptor *descriptor,
+uint64_t ctf_timestamp_begin(struct bt_trace_descriptor *descriptor,
 		struct bt_trace_handle *handle, enum bt_clock_type type)
 {
 	struct ctf_trace *tin;
@@ -202,7 +202,7 @@ error:
 }
 
 static
-uint64_t ctf_timestamp_end(struct trace_descriptor *descriptor,
+uint64_t ctf_timestamp_end(struct bt_trace_descriptor *descriptor,
 		struct bt_trace_handle *handle, enum bt_clock_type type)
 {
 	struct ctf_trace *tin;
@@ -307,6 +307,7 @@ void ctf_update_timestamp(struct ctf_stream_definition *stream,
  * Print timestamp, rescaling clock frequency to nanoseconds and
  * applying offsets as needed (unix time).
  */
+static
 void ctf_print_timestamp_real(FILE *fp,
 			struct ctf_stream_definition *stream,
 			uint64_t timestamp)
@@ -371,6 +372,7 @@ end:
 /*
  * Print timestamp, in cycles
  */
+static
 void ctf_print_timestamp_cycles(FILE *fp,
 		struct ctf_stream_definition *stream,
 		uint64_t timestamp)
@@ -390,7 +392,50 @@ void ctf_print_timestamp(FILE *fp,
 }
 
 static
-int ctf_read_event(struct stream_pos *ppos, struct ctf_stream_definition *stream)
+void print_uuid(FILE *fp, unsigned char *uuid)
+{
+	int i;
+
+	for (i = 0; i < BABELTRACE_UUID_LEN; i++)
+		fprintf(fp, "%x", (unsigned int) uuid[i]);
+}
+
+void ctf_print_discarded(FILE *fp, struct ctf_stream_definition *stream,
+		int end_stream)
+{
+	fprintf(fp, "[warning] Tracer discarded %" PRIu64 " events %sbetween [",
+		stream->events_discarded,
+		end_stream ? "at end of stream " : "");
+	if (opt_clock_cycles) {
+		ctf_print_timestamp(fp, stream,
+				stream->prev_cycles_timestamp);
+		fprintf(fp, "] and [");
+		ctf_print_timestamp(fp, stream,
+				stream->prev_cycles_timestamp_end);
+	} else {
+		ctf_print_timestamp(fp, stream,
+				stream->prev_real_timestamp);
+		fprintf(fp, "] and [");
+		ctf_print_timestamp(fp, stream,
+				stream->prev_real_timestamp_end);
+	}
+	fprintf(fp, "] in trace UUID ");
+	print_uuid(fp, stream->stream_class->trace->uuid);
+	if (stream->stream_class->trace->path[0])
+		fprintf(fp, ", at path: \"%s\"",
+			stream->stream_class->trace->path);
+
+	fprintf(fp, ", within stream id %" PRIu64, stream->stream_id);
+	if (stream->path[0])
+		fprintf(fp, ", at relative path: \"%s\"", stream->path);
+	fprintf(fp, ". ");
+	fprintf(fp, "You should consider recording a new trace with larger "
+		"buffers or with fewer events enabled.\n");
+	fflush(fp);
+}
+
+static
+int ctf_read_event(struct bt_stream_pos *ppos, struct ctf_stream_definition *stream)
 {
 	struct ctf_stream_pos *pos =
 		container_of(ppos, struct ctf_stream_pos, parent);
@@ -419,27 +464,27 @@ int ctf_read_event(struct stream_pos *ppos, struct ctf_stream_definition *stream
 	/* Read event header */
 	if (likely(stream->stream_event_header)) {
 		struct definition_integer *integer_definition;
-		struct definition *variant;
+		struct bt_definition *variant;
 
 		ret = generic_rw(ppos, &stream->stream_event_header->p);
 		if (unlikely(ret))
 			goto error;
 		/* lookup event id */
-		integer_definition = lookup_integer(&stream->stream_event_header->p, "id", FALSE);
+		integer_definition = bt_lookup_integer(&stream->stream_event_header->p, "id", FALSE);
 		if (integer_definition) {
 			id = integer_definition->value._unsigned;
 		} else {
 			struct definition_enum *enum_definition;
 
-			enum_definition = lookup_enum(&stream->stream_event_header->p, "id", FALSE);
+			enum_definition = bt_lookup_enum(&stream->stream_event_header->p, "id", FALSE);
 			if (enum_definition) {
 				id = enum_definition->integer->value._unsigned;
 			}
 		}
 
-		variant = lookup_variant(&stream->stream_event_header->p, "v");
+		variant = bt_lookup_variant(&stream->stream_event_header->p, "v");
 		if (variant) {
-			integer_definition = lookup_integer(variant, "id", FALSE);
+			integer_definition = bt_lookup_integer(variant, "id", FALSE);
 			if (integer_definition) {
 				id = integer_definition->value._unsigned;
 			}
@@ -448,13 +493,13 @@ int ctf_read_event(struct stream_pos *ppos, struct ctf_stream_definition *stream
 
 		/* lookup timestamp */
 		stream->has_timestamp = 0;
-		integer_definition = lookup_integer(&stream->stream_event_header->p, "timestamp", FALSE);
+		integer_definition = bt_lookup_integer(&stream->stream_event_header->p, "timestamp", FALSE);
 		if (integer_definition) {
 			ctf_update_timestamp(stream, integer_definition);
 			stream->has_timestamp = 1;
 		} else {
 			if (variant) {
-				integer_definition = lookup_integer(variant, "timestamp", FALSE);
+				integer_definition = bt_lookup_integer(variant, "timestamp", FALSE);
 				if (integer_definition) {
 					ctf_update_timestamp(stream, integer_definition);
 					stream->has_timestamp = 1;
@@ -502,7 +547,7 @@ error:
 }
 
 static
-int ctf_write_event(struct stream_pos *pos, struct ctf_stream_definition *stream)
+int ctf_write_event(struct bt_stream_pos *pos, struct ctf_stream_definition *stream)
 {
 	struct ctf_stream_declaration *stream_class = stream->stream_class;
 	struct ctf_event_definition *event;
@@ -615,7 +660,7 @@ int ctf_fini_pos(struct ctf_stream_pos *pos)
  * for SEEK_CUR: go to next packet.
  * for SEEK_POS: go to packet numer (index).
  */
-void ctf_packet_seek(struct stream_pos *stream_pos, size_t index, int whence)
+void ctf_packet_seek(struct bt_stream_pos *stream_pos, size_t index, int whence)
 {
 	struct ctf_stream_pos *pos =
 		container_of(stream_pos, struct ctf_stream_pos, parent);
@@ -723,43 +768,26 @@ void ctf_packet_seek(struct stream_pos *stream_pos, size_t index, int whence)
 		}
 		if (pos->cur_index >= pos->packet_real_index->len) {
 			/*
-			 * When a stream reaches the end of the
-			 * file, we need to show the number of
-			 * events discarded ourselves, because
-			 * there is no next event scheduled to
-			 * be printed in the output.
+			 * We need to check if we are in trace read or
+			 * called from packet indexing.  In this last
+			 * case, the collection is not there, so we
+			 * cannot print the timestamps.
 			 */
-			if (file_stream->parent.events_discarded) {
+			if ((&file_stream->parent)->stream_class->trace->collection) {
 				/*
-				 * We need to check if we are in trace
-				 * read or called from packet indexing.
-				 * In this last case, the collection is
-				 * not there, so we cannot print the
-				 * timestamps.
+				 * When a stream reaches the end of the
+				 * file, we need to show the number of
+				 * events discarded ourselves, because
+				 * there is no next event scheduled to
+				 * be printed in the output.
 				 */
-				if ((&file_stream->parent)->stream_class->trace->collection) {
+				if (file_stream->parent.events_discarded) {
 					fflush(stdout);
-					fprintf(stderr, "[warning] Tracer discarded %" PRIu64 " events at end of stream between [",
-							file_stream->parent.events_discarded);
-					if (opt_clock_cycles) {
-						ctf_print_timestamp(stderr,
-								&file_stream->parent,
-								file_stream->parent.prev_cycles_timestamp);
-						fprintf(stderr, "] and [");
-						ctf_print_timestamp(stderr, &file_stream->parent,
-								file_stream->parent.prev_cycles_timestamp_end);
-					} else {
-						ctf_print_timestamp(stderr,
-								&file_stream->parent,
-								file_stream->parent.prev_real_timestamp);
-						fprintf(stderr, "] and [");
-						ctf_print_timestamp(stderr, &file_stream->parent,
-								file_stream->parent.prev_real_timestamp_end);
-					}
-					fprintf(stderr, "]. You should consider recording a new trace with larger buffers or with fewer events enabled.\n");
-					fflush(stderr);
+					ctf_print_discarded(stderr,
+						&file_stream->parent,
+						1);
+					file_stream->parent.events_discarded = 0;
 				}
-				file_stream->parent.events_discarded = 0;
 			}
 			pos->offset = EOF;
 			return;
@@ -959,7 +987,7 @@ int ctf_open_trace_metadata_stream_read(struct ctf_trace *td, FILE **fp,
 					char **buf)
 {
 	FILE *in, *out;
-	size_t size;
+	size_t size, buflen;
 	int ret;
 
 	in = *fp;
@@ -1001,7 +1029,12 @@ int ctf_open_trace_metadata_stream_read(struct ctf_trace *td, FILE **fp,
 		perror("Error in fclose");
 	}
 	/* open for reading */
-	*fp = babeltrace_fmemopen(*buf, strlen(*buf), "rb");
+	buflen = strlen(*buf);
+	if (!buflen) {
+		*fp = NULL;
+		return -ENODATA;
+	}
+	*fp = babeltrace_fmemopen(*buf, buflen, "rb");
 	if (!*fp) {
 		perror("Metadata fmemopen");
 		return -errno;
@@ -1011,7 +1044,7 @@ int ctf_open_trace_metadata_stream_read(struct ctf_trace *td, FILE **fp,
 
 static
 int ctf_open_trace_metadata_read(struct ctf_trace *td,
-		void (*packet_seek)(struct stream_pos *pos, size_t index,
+		void (*packet_seek)(struct bt_stream_pos *pos, size_t index,
 			int whence), FILE *metadata_fp)
 {
 	struct ctf_scanner *scanner;
@@ -1058,8 +1091,11 @@ int ctf_open_trace_metadata_read(struct ctf_trace *td,
 
 	if (packet_metadata(td, fp)) {
 		ret = ctf_open_trace_metadata_stream_read(td, &fp, &buf);
-		if (ret)
+		if (ret) {
+			/* Warn about empty metadata */
+			fprintf(stderr, "[warning] Empty metadata.\n");
 			goto end_packet_read;
+		}
 	} else {
 		unsigned int major, minor;
 		ssize_t nr_items;
@@ -1140,7 +1176,7 @@ struct ctf_event_definition *create_event_definitions(struct ctf_trace *td,
 	struct ctf_event_definition *stream_event = g_new0(struct ctf_event_definition, 1);
 
 	if (event->context_decl) {
-		struct definition *definition =
+		struct bt_definition *definition =
 			event->context_decl->p.definition_new(&event->context_decl->p,
 				stream->parent_def_scope, 0, 0, "event.context");
 		if (!definition) {
@@ -1151,7 +1187,7 @@ struct ctf_event_definition *create_event_definitions(struct ctf_trace *td,
 		stream->parent_def_scope = stream_event->event_context->p.scope;
 	}
 	if (event->fields_decl) {
-		struct definition *definition =
+		struct bt_definition *definition =
 			event->fields_decl->p.definition_new(&event->fields_decl->p,
 				stream->parent_def_scope, 0, 0, "event.fields");
 		if (!definition) {
@@ -1166,9 +1202,9 @@ struct ctf_event_definition *create_event_definitions(struct ctf_trace *td,
 
 error:
 	if (stream_event->event_fields)
-		definition_unref(&stream_event->event_fields->p);
+		bt_definition_unref(&stream_event->event_fields->p);
 	if (stream_event->event_context)
-		definition_unref(&stream_event->event_context->p);
+		bt_definition_unref(&stream_event->event_context->p);
 	return NULL;
 }
 
@@ -1185,7 +1221,7 @@ int create_stream_definitions(struct ctf_trace *td, struct ctf_stream_definition
 	stream_class = stream->stream_class;
 
 	if (stream_class->packet_context_decl) {
-		struct definition *definition =
+		struct bt_definition *definition =
 			stream_class->packet_context_decl->p.definition_new(&stream_class->packet_context_decl->p,
 				stream->parent_def_scope, 0, 0, "stream.packet.context");
 		if (!definition) {
@@ -1197,7 +1233,7 @@ int create_stream_definitions(struct ctf_trace *td, struct ctf_stream_definition
 		stream->parent_def_scope = stream->stream_packet_context->p.scope;
 	}
 	if (stream_class->event_header_decl) {
-		struct definition *definition =
+		struct bt_definition *definition =
 			stream_class->event_header_decl->p.definition_new(&stream_class->event_header_decl->p,
 				stream->parent_def_scope, 0, 0, "stream.event.header");
 		if (!definition) {
@@ -1209,7 +1245,7 @@ int create_stream_definitions(struct ctf_trace *td, struct ctf_stream_definition
 		stream->parent_def_scope = stream->stream_event_header->p.scope;
 	}
 	if (stream_class->event_context_decl) {
-		struct definition *definition =
+		struct bt_definition *definition =
 			stream_class->event_context_decl->p.definition_new(&stream_class->event_context_decl->p,
 				stream->parent_def_scope, 0, 0, "stream.event.context");
 		if (!definition) {
@@ -1244,11 +1280,11 @@ error_event:
 	g_ptr_array_free(stream->events_by_id, TRUE);
 error:
 	if (stream->stream_event_context)
-		definition_unref(&stream->stream_event_context->p);
+		bt_definition_unref(&stream->stream_event_context->p);
 	if (stream->stream_event_header)
-		definition_unref(&stream->stream_event_header->p);
+		bt_definition_unref(&stream->stream_event_header->p);
 	if (stream->stream_packet_context)
-		definition_unref(&stream->stream_packet_context->p);
+		bt_definition_unref(&stream->stream_packet_context->p);
 	return ret;
 }
 
@@ -1309,13 +1345,13 @@ int create_stream_packet_index(struct ctf_trace *td,
 			ret = generic_rw(&pos->parent, &file_stream->parent.trace_packet_header->p);
 			if (ret)
 				return ret;
-			len_index = struct_declaration_lookup_field_index(file_stream->parent.trace_packet_header->declaration, g_quark_from_static_string("magic"));
+			len_index = bt_struct_declaration_lookup_field_index(file_stream->parent.trace_packet_header->declaration, g_quark_from_static_string("magic"));
 			if (len_index >= 0) {
-				struct definition *field;
+				struct bt_definition *field;
 				uint64_t magic;
 
-				field = struct_definition_get_field_from_index(file_stream->parent.trace_packet_header, len_index);
-				magic = get_unsigned_int(field);
+				field = bt_struct_definition_get_field_from_index(file_stream->parent.trace_packet_header, len_index);
+				magic = bt_get_unsigned_int(field);
 				if (magic != CTF_MAGIC) {
 					fprintf(stderr, "[error] Invalid magic number 0x%" PRIX64 " at packet %u (file offset %zd).\n",
 							magic,
@@ -1326,23 +1362,23 @@ int create_stream_packet_index(struct ctf_trace *td,
 			}
 
 			/* check uuid */
-			len_index = struct_declaration_lookup_field_index(file_stream->parent.trace_packet_header->declaration, g_quark_from_static_string("uuid"));
+			len_index = bt_struct_declaration_lookup_field_index(file_stream->parent.trace_packet_header->declaration, g_quark_from_static_string("uuid"));
 			if (len_index >= 0) {
 				struct definition_array *defarray;
-				struct definition *field;
+				struct bt_definition *field;
 				uint64_t i;
 				uint8_t uuidval[BABELTRACE_UUID_LEN];
 
-				field = struct_definition_get_field_from_index(file_stream->parent.trace_packet_header, len_index);
+				field = bt_struct_definition_get_field_from_index(file_stream->parent.trace_packet_header, len_index);
 				assert(field->declaration->id == CTF_TYPE_ARRAY);
 				defarray = container_of(field, struct definition_array, p);
-				assert(array_len(defarray) == BABELTRACE_UUID_LEN);
+				assert(bt_array_len(defarray) == BABELTRACE_UUID_LEN);
 
 				for (i = 0; i < BABELTRACE_UUID_LEN; i++) {
-					struct definition *elem;
+					struct bt_definition *elem;
 
-					elem = array_index(defarray, i);
-					uuidval[i] = get_unsigned_int(elem);
+					elem = bt_array_index(defarray, i);
+					uuidval[i] = bt_get_unsigned_int(elem);
 				}
 				ret = babeltrace_uuid_compare(td->uuid, uuidval);
 				if (ret) {
@@ -1352,17 +1388,19 @@ int create_stream_packet_index(struct ctf_trace *td,
 			}
 
 
-			len_index = struct_declaration_lookup_field_index(file_stream->parent.trace_packet_header->declaration, g_quark_from_static_string("stream_id"));
+			len_index = bt_struct_declaration_lookup_field_index(file_stream->parent.trace_packet_header->declaration, g_quark_from_static_string("stream_id"));
 			if (len_index >= 0) {
-				struct definition *field;
+				struct bt_definition *field;
 
-				field = struct_definition_get_field_from_index(file_stream->parent.trace_packet_header, len_index);
-				stream_id = get_unsigned_int(field);
+				field = bt_struct_definition_get_field_from_index(file_stream->parent.trace_packet_header, len_index);
+				stream_id = bt_get_unsigned_int(field);
 			}
 		}
 
 		if (!first_packet && file_stream->parent.stream_id != stream_id) {
-			fprintf(stderr, "[error] Stream ID is changing within a stream.\n");
+			fprintf(stderr, "[error] Stream ID is changing within a stream: expecting %" PRIu64 ", but packet has %" PRIu64 "\n",
+				stream_id,
+				file_stream->parent.stream_id);
 			return -EINVAL;
 		}
 		if (first_packet) {
@@ -1389,36 +1427,36 @@ int create_stream_packet_index(struct ctf_trace *td,
 			if (ret)
 				return ret;
 			/* read content size from header */
-			len_index = struct_declaration_lookup_field_index(file_stream->parent.stream_packet_context->declaration, g_quark_from_static_string("content_size"));
+			len_index = bt_struct_declaration_lookup_field_index(file_stream->parent.stream_packet_context->declaration, g_quark_from_static_string("content_size"));
 			if (len_index >= 0) {
-				struct definition *field;
+				struct bt_definition *field;
 
-				field = struct_definition_get_field_from_index(file_stream->parent.stream_packet_context, len_index);
-				packet_index.content_size = get_unsigned_int(field);
+				field = bt_struct_definition_get_field_from_index(file_stream->parent.stream_packet_context, len_index);
+				packet_index.content_size = bt_get_unsigned_int(field);
 			} else {
 				/* Use file size for packet size */
 				packet_index.content_size = filestats.st_size * CHAR_BIT;
 			}
 
 			/* read packet size from header */
-			len_index = struct_declaration_lookup_field_index(file_stream->parent.stream_packet_context->declaration, g_quark_from_static_string("packet_size"));
+			len_index = bt_struct_declaration_lookup_field_index(file_stream->parent.stream_packet_context->declaration, g_quark_from_static_string("packet_size"));
 			if (len_index >= 0) {
-				struct definition *field;
+				struct bt_definition *field;
 
-				field = struct_definition_get_field_from_index(file_stream->parent.stream_packet_context, len_index);
-				packet_index.packet_size = get_unsigned_int(field);
+				field = bt_struct_definition_get_field_from_index(file_stream->parent.stream_packet_context, len_index);
+				packet_index.packet_size = bt_get_unsigned_int(field);
 			} else {
 				/* Use content size if non-zero, else file size */
 				packet_index.packet_size = packet_index.content_size ? : filestats.st_size * CHAR_BIT;
 			}
 
 			/* read timestamp begin from header */
-			len_index = struct_declaration_lookup_field_index(file_stream->parent.stream_packet_context->declaration, g_quark_from_static_string("timestamp_begin"));
+			len_index = bt_struct_declaration_lookup_field_index(file_stream->parent.stream_packet_context->declaration, g_quark_from_static_string("timestamp_begin"));
 			if (len_index >= 0) {
-				struct definition *field;
+				struct bt_definition *field;
 
-				field = struct_definition_get_field_from_index(file_stream->parent.stream_packet_context, len_index);
-				packet_index.timestamp_begin = get_unsigned_int(field);
+				field = bt_struct_definition_get_field_from_index(file_stream->parent.stream_packet_context, len_index);
+				packet_index.timestamp_begin = bt_get_unsigned_int(field);
 				if (file_stream->parent.stream_class->trace->collection) {
 					packet_index.timestamp_begin =
 						ctf_get_real_timestamp(
@@ -1428,12 +1466,12 @@ int create_stream_packet_index(struct ctf_trace *td,
 			}
 
 			/* read timestamp end from header */
-			len_index = struct_declaration_lookup_field_index(file_stream->parent.stream_packet_context->declaration, g_quark_from_static_string("timestamp_end"));
+			len_index = bt_struct_declaration_lookup_field_index(file_stream->parent.stream_packet_context->declaration, g_quark_from_static_string("timestamp_end"));
 			if (len_index >= 0) {
-				struct definition *field;
+				struct bt_definition *field;
 
-				field = struct_definition_get_field_from_index(file_stream->parent.stream_packet_context, len_index);
-				packet_index.timestamp_end = get_unsigned_int(field);
+				field = bt_struct_definition_get_field_from_index(file_stream->parent.stream_packet_context, len_index);
+				packet_index.timestamp_end = bt_get_unsigned_int(field);
 				if (file_stream->parent.stream_class->trace->collection) {
 					packet_index.timestamp_end =
 						ctf_get_real_timestamp(
@@ -1443,13 +1481,13 @@ int create_stream_packet_index(struct ctf_trace *td,
 			}
 
 			/* read events discarded from header */
-			len_index = struct_declaration_lookup_field_index(file_stream->parent.stream_packet_context->declaration, g_quark_from_static_string("events_discarded"));
+			len_index = bt_struct_declaration_lookup_field_index(file_stream->parent.stream_packet_context->declaration, g_quark_from_static_string("events_discarded"));
 			if (len_index >= 0) {
-				struct definition *field;
+				struct bt_definition *field;
 
-				field = struct_definition_get_field_from_index(file_stream->parent.stream_packet_context, len_index);
-				packet_index.events_discarded = get_unsigned_int(field);
-				packet_index.events_discarded_len = get_int_len(field);
+				field = bt_struct_definition_get_field_from_index(file_stream->parent.stream_packet_context, len_index);
+				packet_index.events_discarded = bt_get_unsigned_int(field);
+				packet_index.events_discarded_len = bt_get_int_len(field);
 			}
 		} else {
 			/* Use file size for packet size */
@@ -1489,7 +1527,7 @@ int create_trace_definitions(struct ctf_trace *td, struct ctf_stream_definition
 	int ret;
 
 	if (td->packet_header_decl) {
-		struct definition *definition =
+		struct bt_definition *definition =
 			td->packet_header_decl->p.definition_new(&td->packet_header_decl->p,
 				stream->parent_def_scope, 0, 0, "trace.packet.header");
 		if (!definition) {
@@ -1513,7 +1551,7 @@ error:
  */
 static
 int ctf_open_file_stream_read(struct ctf_trace *td, const char *path, int flags,
-		void (*packet_seek)(struct stream_pos *pos, size_t index,
+		void (*packet_seek)(struct bt_stream_pos *pos, size_t index,
 			int whence))
 {
 	int ret, fd, closeret;
@@ -1542,6 +1580,9 @@ int ctf_open_file_stream_read(struct ctf_trace *td, const char *path, int flags,
 	file_stream = g_new0(struct ctf_file_stream, 1);
 	file_stream->pos.last_offset = LAST_OFFSET_POISON;
 
+	strncpy(file_stream->parent.path, path, PATH_MAX);
+	file_stream->parent.path[PATH_MAX - 1] = '\0';
+
 	if (packet_seek) {
 		file_stream->pos.packet_seek = packet_seek;
 	} else {
@@ -1570,7 +1611,7 @@ int ctf_open_file_stream_read(struct ctf_trace *td, const char *path, int flags,
 
 error_index:
 	if (file_stream->parent.trace_packet_header)
-		definition_unref(&file_stream->parent.trace_packet_header->p);
+		bt_definition_unref(&file_stream->parent.trace_packet_header->p);
 error_def:
 	closeret = ctf_fini_pos(&file_stream->pos);
 	if (closeret) {
@@ -1590,7 +1631,7 @@ error:
 static
 int ctf_open_trace_read(struct ctf_trace *td,
 		const char *path, int flags,
-		void (*packet_seek)(struct stream_pos *pos, size_t index,
+		void (*packet_seek)(struct bt_stream_pos *pos, size_t index,
 			int whence), FILE *metadata_fp)
 {
 	int ret, closeret;
@@ -1685,8 +1726,8 @@ error:
  * since the index creation read it entirely.
  */
 static
-struct trace_descriptor *ctf_open_trace(const char *path, int flags,
-		void (*packet_seek)(struct stream_pos *pos, size_t index,
+struct bt_trace_descriptor *ctf_open_trace(const char *path, int flags,
+		void (*packet_seek)(struct bt_stream_pos *pos, size_t index,
 			int whence), FILE *metadata_fp)
 {
 	struct ctf_trace *td;
@@ -1724,9 +1765,9 @@ error:
 	return NULL;
 }
 
-
+static
 void ctf_init_mmap_pos(struct ctf_stream_pos *pos,
-		struct mmap_stream *mmap_info)
+		struct bt_mmap_stream *mmap_info)
 {
 	pos->mmap_offset = 0;
 	pos->packet_size = 0;
@@ -1775,8 +1816,8 @@ end:
 
 static
 int ctf_open_mmap_stream_read(struct ctf_trace *td,
-		struct mmap_stream *mmap_info,
-		void (*packet_seek)(struct stream_pos *pos, size_t index,
+		struct bt_mmap_stream *mmap_info,
+		void (*packet_seek)(struct bt_stream_pos *pos, size_t index,
 			int whence))
 {
 	int ret;
@@ -1809,20 +1850,21 @@ int ctf_open_mmap_stream_read(struct ctf_trace *td,
 
 error_index:
 	if (file_stream->parent.trace_packet_header)
-		definition_unref(&file_stream->parent.trace_packet_header->p);
+		bt_definition_unref(&file_stream->parent.trace_packet_header->p);
 error_def:
 	g_free(file_stream);
 	return ret;
 }
 
+static
 int ctf_open_mmap_trace_read(struct ctf_trace *td,
-		struct mmap_stream_list *mmap_list,
-		void (*packet_seek)(struct stream_pos *pos, size_t index,
+		struct bt_mmap_stream_list *mmap_list,
+		void (*packet_seek)(struct bt_stream_pos *pos, size_t index,
 			int whence),
 		FILE *metadata_fp)
 {
 	int ret;
-	struct mmap_stream *mmap_info;
+	struct bt_mmap_stream *mmap_info;
 
 	ret = ctf_open_trace_metadata_read(td, ctf_packet_seek, metadata_fp);
 	if (ret) {
@@ -1848,9 +1890,9 @@ error:
 }
 
 static
-struct trace_descriptor *ctf_open_mmap_trace(
-		struct mmap_stream_list *mmap_list,
-		void (*packet_seek)(struct stream_pos *pos, size_t index,
+struct bt_trace_descriptor *ctf_open_mmap_trace(
+		struct bt_mmap_stream_list *mmap_list,
+		void (*packet_seek)(struct bt_stream_pos *pos, size_t index,
 			int whence),
 		FILE *metadata_fp)
 {
@@ -1880,7 +1922,7 @@ error:
 }
 
 static
-int ctf_convert_index_timestamp(struct trace_descriptor *tdp)
+int ctf_convert_index_timestamp(struct bt_trace_descriptor *tdp)
 {
 	int i, j, k;
 	struct ctf_trace *td = container_of(tdp, struct ctf_trace, parent);
@@ -1948,7 +1990,7 @@ int ctf_close_file_stream(struct ctf_file_stream *file_stream)
 }
 
 static
-int ctf_close_trace(struct trace_descriptor *tdp)
+int ctf_close_trace(struct bt_trace_descriptor *tdp)
 {
 	struct ctf_trace *td = container_of(tdp, struct ctf_trace, parent);
 	int ret;
@@ -1989,7 +2031,7 @@ int ctf_close_trace(struct trace_descriptor *tdp)
 }
 
 static
-void ctf_set_context(struct trace_descriptor *descriptor,
+void ctf_set_context(struct bt_trace_descriptor *descriptor,
 		struct bt_context *ctx)
 {
 	struct ctf_trace *td = container_of(descriptor, struct ctf_trace,
@@ -1999,7 +2041,7 @@ void ctf_set_context(struct trace_descriptor *descriptor,
 }
 
 static
-void ctf_set_handle(struct trace_descriptor *descriptor,
+void ctf_set_handle(struct bt_trace_descriptor *descriptor,
 		struct bt_trace_handle *handle)
 {
 	struct ctf_trace *td = container_of(descriptor, struct ctf_trace,
