@@ -32,13 +32,13 @@
 #include <inttypes.h>
 
 static
-struct definition *_array_definition_new(struct declaration *declaration,
+struct bt_definition *_array_definition_new(struct bt_declaration *declaration,
 			struct definition_scope *parent_scope,
 			GQuark field_name, int index, const char *root_name);
 static
-void _array_definition_free(struct definition *definition);
+void _array_definition_free(struct bt_definition *definition);
 
-int array_rw(struct stream_pos *pos, struct definition *definition)
+int bt_array_rw(struct bt_stream_pos *pos, struct bt_definition *definition)
 {
 	struct definition_array *array_definition =
 		container_of(definition, struct definition_array, p);
@@ -49,7 +49,7 @@ int array_rw(struct stream_pos *pos, struct definition *definition)
 
 	/* No need to align, because the first field will align itself. */
 	for (i = 0; i < array_declaration->len; i++) {
-		struct definition *field =
+		struct bt_definition *field =
 			g_ptr_array_index(array_definition->elems, i);
 		ret = generic_rw(pos, field);
 		if (ret)
@@ -59,30 +59,30 @@ int array_rw(struct stream_pos *pos, struct definition *definition)
 }
 
 static
-void _array_declaration_free(struct declaration *declaration)
+void _array_declaration_free(struct bt_declaration *declaration)
 {
 	struct declaration_array *array_declaration =
 		container_of(declaration, struct declaration_array, p);
 
-	free_declaration_scope(array_declaration->scope);
-	declaration_unref(array_declaration->elem);
+	bt_free_declaration_scope(array_declaration->scope);
+	bt_declaration_unref(array_declaration->elem);
 	g_free(array_declaration);
 }
 
 struct declaration_array *
-	array_declaration_new(size_t len,
-			      struct declaration *elem_declaration,
+	bt_array_declaration_new(size_t len,
+			      struct bt_declaration *elem_declaration,
 			      struct declaration_scope *parent_scope)
 {
 	struct declaration_array *array_declaration;
-	struct declaration *declaration;
+	struct bt_declaration *declaration;
 
 	array_declaration = g_new(struct declaration_array, 1);
 	declaration = &array_declaration->p;
 	array_declaration->len = len;
-	declaration_ref(elem_declaration);
+	bt_declaration_ref(elem_declaration);
 	array_declaration->elem = elem_declaration;
-	array_declaration->scope = new_declaration_scope(parent_scope);
+	array_declaration->scope = bt_new_declaration_scope(parent_scope);
 	declaration->id = CTF_TYPE_ARRAY;
 	declaration->alignment = elem_declaration->alignment;
 	declaration->declaration_free = _array_declaration_free;
@@ -93,8 +93,8 @@ struct declaration_array *
 }
 
 static
-struct definition *
-	_array_definition_new(struct declaration *declaration,
+struct bt_definition *
+	_array_definition_new(struct bt_declaration *declaration,
 			      struct definition_scope *parent_scope,
 			      GQuark field_name, int index, const char *root_name)
 {
@@ -105,7 +105,7 @@ struct definition *
 	int i;
 
 	array = g_new(struct definition_array, 1);
-	declaration_ref(&array_declaration->p);
+	bt_declaration_ref(&array_declaration->p);
 	array->p.declaration = declaration;
 	array->declaration = array_declaration;
 	array->p.ref = 1;
@@ -115,9 +115,9 @@ struct definition *
 	 */
 	array->p.index = root_name ? INT_MAX : index;
 	array->p.name = field_name;
-	array->p.path = new_definition_path(parent_scope, field_name, root_name);
-	array->p.scope = new_definition_scope(parent_scope, field_name, root_name);
-	ret = register_field_definition(field_name, &array->p,
+	array->p.path = bt_new_definition_path(parent_scope, field_name, root_name);
+	array->p.scope = bt_new_definition_scope(parent_scope, field_name, root_name);
+	ret = bt_register_field_definition(field_name, &array->p,
 					parent_scope);
 	assert(!ret);
 	array->string = NULL;
@@ -142,7 +142,7 @@ struct definition *
 	array->elems = g_ptr_array_sized_new(array_declaration->len);
 	g_ptr_array_set_size(array->elems, array_declaration->len);
 	for (i = 0; i < array_declaration->len; i++) {
-		struct definition **field;
+		struct bt_definition **field;
 		GString *str;
 		GQuark name;
 
@@ -151,7 +151,7 @@ struct definition *
 		name = g_quark_from_string(str->str);
 		(void) g_string_free(str, TRUE);
 
-		field = (struct definition **) &g_ptr_array_index(array->elems, i);
+		field = (struct bt_definition **) &g_ptr_array_index(array->elems, i);
 		*field = array_declaration->elem->definition_new(array_declaration->elem,
 					  array->p.scope,
 					  name, i, NULL);
@@ -163,20 +163,20 @@ struct definition *
 
 error:
 	for (i--; i >= 0; i--) {
-		struct definition *field;
+		struct bt_definition *field;
 
 		field = g_ptr_array_index(array->elems, i);
 		field->declaration->definition_free(field);
 	}
 	(void) g_ptr_array_free(array->elems, TRUE);
-	free_definition_scope(array->p.scope);
-	declaration_unref(array->p.declaration);
+	bt_free_definition_scope(array->p.scope);
+	bt_declaration_unref(array->p.declaration);
 	g_free(array);
 	return NULL;
 }
 
 static
-void _array_definition_free(struct definition *definition)
+void _array_definition_free(struct bt_definition *definition)
 {
 	struct definition_array *array =
 		container_of(definition, struct definition_array, p);
@@ -186,26 +186,26 @@ void _array_definition_free(struct definition *definition)
 		(void) g_string_free(array->string, TRUE);
 	if (array->elems) {
 		for (i = 0; i < array->elems->len; i++) {
-			struct definition *field;
+			struct bt_definition *field;
 
 			field = g_ptr_array_index(array->elems, i);
 			field->declaration->definition_free(field);
 		}
 		(void) g_ptr_array_free(array->elems, TRUE);
 	}
-	free_definition_scope(array->p.scope);
-	declaration_unref(array->p.declaration);
+	bt_free_definition_scope(array->p.scope);
+	bt_declaration_unref(array->p.declaration);
 	g_free(array);
 }
 
-uint64_t array_len(struct definition_array *array)
+uint64_t bt_array_len(struct definition_array *array)
 {
 	if (!array->elems)
 		return array->string->len;
 	return array->elems->len;
 }
 
-struct definition *array_index(struct definition_array *array, uint64_t i)
+struct bt_definition *bt_array_index(struct definition_array *array, uint64_t i)
 {
 	if (!array->elems)
 		return NULL;
@@ -214,7 +214,7 @@ struct definition *array_index(struct definition_array *array, uint64_t i)
 	return g_ptr_array_index(array->elems, i);
 }
 
-int get_array_len(const struct definition *field)
+int bt_get_array_len(const struct bt_definition *field)
 {
 	struct definition_array *array_definition;
 	struct declaration_array *array_declaration;
@@ -225,11 +225,11 @@ int get_array_len(const struct definition *field)
 	return array_declaration->len;
 }
 
-GString *get_char_array(const struct definition *field)
+GString *bt_get_char_array(const struct bt_definition *field)
 {
 	struct definition_array *array_definition;
 	struct declaration_array *array_declaration;
-	struct declaration *elem;
+	struct bt_declaration *elem;
 
 	array_definition = container_of(field, struct definition_array, p);
 	array_declaration = array_definition->declaration;
